@@ -3,7 +3,8 @@
 
 """Namespace for sklearn models."""
 
-from .sklearn_model_utils import (create_kneighbors_classifier,
+from .sklearn_model_utils import (create_complex_classification_pipeline,
+                                  create_kneighbors_classifier,
                                   create_sklearn_logistic_regressor,
                                   create_sklearn_random_forest_classifier,
                                   create_sklearn_random_forest_regressor,
@@ -16,5 +17,6 @@ __all__ = [
     create_sklearn_random_forest_classifier,
     create_sklearn_random_forest_regressor,
     create_sklearn_svm_classifier,
-    create_titanic_pipeline
+    create_titanic_pipeline,
+    create_complex_classification_pipeline
 ]
